# Experiments
:test_tube:	**This section is for experiments**

We commit and record results from different experiments done using Ragas here. We do two types of experiments,
1. `assesments` : To develop better metrics,paradigms and evaluate metrics against human judgment.
2. `baselines`: Create RAG pipelines and evaluate them using Ragas.

Any machine learning comprehension dataset can be used for experiments. Add any newly tried dataset to below list.
Datasets:
1. [HotpotQA](https://huggingface.co/datasets/hotpot_qa)
2. [WikiQA test](explodinggradients/ragas-wikiqa)

